# @self/spaces-test

## 0.0.1

### Dependency updates

- @gradio/client@2.1.0

## 0.0.1

### Dependency updates

- @gradio/client@2.0.4

## 0.0.1

### Dependency updates

- @gradio/client@2.0.3
- @gradio/theme@0.6.1

## 0.0.1

### Dependency updates

- @gradio/client@2.0.2
- @gradio/theme@0.6.0

## 0.0.1

### Dependency updates

- @gradio/client@2.0.1

## 0.0.1

### Dependency updates

- @gradio/client@2.0.0-dev.2

## 0.0.1

### Dependency updates

- @gradio/theme@0.5.0-dev.0

## 0.0.1

### Dependency updates

- @gradio/client@2.0.0-dev.1

## 0.0.1

### Dependency updates

- @gradio/client@2.0.0-dev.0

## 0.0.1

### Dependency updates

- @gradio/client@1.19.1

## 0.0.1

### Dependency updates

- @gradio/client@1.19.0

## 0.0.1

### Dependency updates

- @gradio/client@1.18.0

## 0.0.1

### Dependency updates

- @gradio/client@1.17.1

## 0.0.1

### Dependency updates

- @gradio/client@1.17.0

## 0.0.1

### Dependency updates

- @gradio/client@1.16.0

## 0.0.1

### Dependency updates

- @gradio/client@1.15.7

## 0.0.1

### Dependency updates

- @gradio/client@1.15.6

## 0.0.1

### Dependency updates

- @gradio/client@1.15.5

## 0.0.1

### Dependency updates

- @gradio/client@1.15.4

## 0.0.1

### Dependency updates

- @gradio/client@1.15.3

## 0.0.1

### Dependency updates

- @gradio/client@1.15.2

## 0.0.1

### Dependency updates

- @gradio/client@1.15.1

## 0.0.1

### Dependency updates

- @gradio/client@1.15.0

## 0.0.1

### Dependency updates

- @gradio/client@1.14.2

## 0.0.1

### Dependency updates

- @gradio/client@1.14.1

## 0.0.1

### Dependency updates

- @gradio/client@1.14.0

## 0.0.1

### Dependency updates

- @gradio/client@1.13.1

## 0.0.1

### Dependency updates

- @gradio/client@1.13.0

## 0.0.1

### Dependency updates

- @gradio/theme@0.4.0
- @gradio/client@1.12.0

## 0.0.1

### Dependency updates

- @gradio/client@1.11.0

## 0.0.1

### Dependency updates

- @gradio/client@1.10.0

## 0.0.1

### Dependency updates

- @gradio/client@1.9.0

## 0.0.1

### Dependency updates

- @gradio/client@1.8.0

## 0.0.1

### Dependency updates

- @gradio/client@1.7.1

## 0.0.1

### Dependency updates

- @gradio/client@1.7.0

## 0.0.1

### Dependency updates

- @gradio/client@1.6.0-beta.4

## 0.0.1

### Dependency updates

- @gradio/client@1.6.0-beta.3

## 0.0.1

### Dependency updates

- @gradio/client@1.6.0-beta.2

## 0.0.1

### Dependency updates

- @gradio/client@1.6.0-beta.1
- @gradio/theme@0.3.0-beta.1

## 0.0.1

### Dependency updates

- @gradio/client@1.5.1
- @gradio/theme@0.2.4

## 0.0.1

### Dependency updates

- @gradio/client@1.5.0
- @gradio/form@0.1.23

## 0.0.1

### Dependency updates

- @gradio/form@0.1.22

## 0.0.1

### Dependency updates

- @gradio/client@1.4.0
- @gradio/form@0.1.21

## 0.0.1

### Dependency updates

- @gradio/client@1.3.0
- @gradio/form@0.1.20

## 0.0.1

### Dependency updates

- @gradio/client@1.2.1

## 0.0.1

### Dependency updates

- @gradio/client@1.2.0
- @gradio/form@0.1.19

## 0.0.1

### Dependency updates

- @gradio/client@1.1.1

## 0.0.1

### Dependency updates

- @gradio/client@1.1.0

## 0.0.1

### Dependency updates

- @gradio/client@1.0.0
- @gradio/form@0.1.18

## 0.0.1

### Dependency updates

- @gradio/client@0.20.1

## 0.0.1

### Dependency updates

- @gradio/client@0.20.0

## 0.0.1

### Dependency updates

- @gradio/theme@0.2.3
- @gradio/client@0.19.4
- @gradio/form@0.1.18

## 0.0.1

### Dependency updates

- @gradio/client@0.19.3

## 0.0.1

### Dependency updates

- @gradio/client@0.19.2

## 0.0.1

### Dependency updates

- @gradio/client@0.19.1

## 0.0.1

### Dependency updates

- @gradio/client@0.19.0
- @gradio/form@0.1.17

## 0.0.1

### Dependency updates

- @gradio/client@0.18.0
- @gradio/form@0.1.16

## 0.0.1

### Dependency updates

- @gradio/client@0.17.0
- @gradio/form@0.1.15

## 0.0.1

### Dependency updates

- @gradio/theme@0.2.2
- @gradio/client@0.16.0
- @gradio/form@0.1.14

## 0.0.1

### Dependency updates

- @gradio/theme@0.2.1
- @gradio/client@0.15.1
- @gradio/form@0.1.13

## 0.0.1

### Dependency updates

- @gradio/client@0.15.0

## 0.0.1

### Dependency updates

- @gradio/form@0.1.12

## 0.0.1

### Dependency updates

- @gradio/form@0.1.11

## 0.0.1

### Dependency updates

- @gradio/client@0.14.0

## 0.0.1

### Dependency updates

- @gradio/client@0.13.0